# wexample-prompt

Helper for your tty interactions

Version: 0.0.50

## Requirements

- Python >=3.10

## Dependencies

- attrs>=23.1.0
- cattrs>=23.1.0
- colorama
- inquirerpy
- readchar
- wexample-helpers==0.0.68

## Installation

```bash
pip install wexample-prompt
```

## Links

- Homepage: https://github.com/wexample/python-prompt

## License

MIT
## Credits

This package has been developed by [Wexample](https://wexample.com), a collection of tools and utilities to streamline development workflows.

Visit [wexample.com](https://wexample.com) to discover more tools and resources for efficient development.